<?php

/*
 * fieldday Shortcodes
 * @package fieldday
 * @since   1.0.0
 */

class fielddayShortcodes
{

    function __construct()
    {
        /**
         * Shortcode to display the list of session in front end through shortcodes
         * [fieldday_sessions]
         */
        add_shortcode('fieldday_sessions', [$this, 'fielddaySessions']);
        /**
         * Shortcode to display login forms
         * [fieldday_login]
         */
        add_shortcode('fieldday_login', [$this, 'fielddayLogin']);

        /**
         * Shortcode to display register forms
         * [fieldday_login]
         */
        add_shortcode('fieldday_register', [$this, 'fielddayRegister']);

        /**
         * Shortcode to display user profile
         * [fieldday_profile]
         */
        add_shortcode('fieldday_profile', [$this, 'fielddayProfile']);

        /**
         * this shortcode will display the checkout page content
         *
         * [fieldday_checkout]
         */
        add_shortcode('fieldday_checkout', [$this, 'fielddayCheckout']);

        /**
         * this shortcode will display the donate form
         *
         * [fieldday_donate event_name="" event_description="" column="1 0r 2" success_message=""]
         */
        add_shortcode('fieldday_donate', [$this, 'fielddayDonate']);
    }

    /**
     * display sessions from a provider
     * @param array  $arg  Shortcode arguments
     *
     * @global array $fielddaySetting
     * @throws ApiException on a non 2xx response
     * @return HTML
     */
    public function fielddaySessions($arg = [])
    {
        global $fielddaySetting;
        $query_options = [];
        $tagId = filter_input(INPUT_GET, 'tagId', FILTER_SANITIZE_STRING);
        $activityId = filter_input(INPUT_GET, 'activityId', FILTER_SANITIZE_STRING);
        $sessionId = filter_input(INPUT_GET, '_id', FILTER_SANITIZE_STRING);
        $activityTags = fieldday()->api->getActivityTagsCount();
        /* is sessionId filter from url */
        if ($sessionId)
        {
            $query_options['filters']['sessionId'] = $sessionId;
        }
        
        if($activityId) {
            $query_options['filters']['activityId'] = $activityId;
        }
        if ($activityTags->statusCode == 200)
        {
            foreach ($activityTags->data as $key => $tags)
            {
                if ($tagId)
                {
                    $query_options['tagId'] = $tagId;
                } else
                {
                    if ($tags->title == "Full Week")
                    {
                        $query_options['tagId'] = $tags->_id;
                        $tagId = $tags->_id;
                    }
                }
            }
        } else
        {
            print fieldday()->engine->displayFlash('error', __($activityTags->message, 'fieldday'));
        }
        /* activity tags */
        $activityTypes = fieldday()->api->getActivityTags();
        if ($activityTypes->data && count((array) $activityTypes->data))
        {
            $tabId = $activityTypes->data[0]->_id;
        }

        return fieldday()->engine->getView('sessions_list', ['activityTags' => $activityTags, 'tagId' => $tagId, 'filters' => $query_options, 'activityTypes' => $activityTypes, 'tabId' => $tabId]);
    }

    /**
     * display login page
     * @param array  $arg  Shortcode arguments
     * @throws ApiException on a non 2xx response
     * @return HTML
     */
    public function fielddayLogin($arg = [])
    {
        $action = filter_input(INPUT_GET, 'action', FILTER_SANITIZE_STRING);
        if ($action == 'km_register')
        {

            return fieldday()->engine->getView('register');
        }
        return fieldday()->engine->getView('login');
    }

    /**
     * display register page
     * @param array  $arg  Shortcode arguments
     * @throws ApiException on a non 2xx response
     * @return HTML
     */
    public function fielddayRegister($arg = [])
    {
        global $KmUser;
        if (is_user_logged_in() && $KmUser)
        {
            return fieldday()->engine->getView('account/_myaccount', ['KmUser' => $KmUser]);
        }

        $action = filter_input(INPUT_GET, 'action', FILTER_SANITIZE_STRING);
        if ($action == 'km_login')
        {

            return fieldday()->engine->getView('login');
        }

        return fieldday()->engine->getView('register');
    }

    /**
     * display loggedin user profile
     * @param array  $arg  Shortcode arguments
     * @throws ApiException on a non 2xx response
     * @return HTML
     */
    public function fielddayProfile($arg = [])
    {
        global $KmUser;
        $action = filter_input(INPUT_GET, 'action', FILTER_SANITIZE_STRING);
        if (!$KmUser)
        {
            return fieldday()->engine->getView('account/_loginrequired');
        }
        switch ($action)
        {
            case "myaccount":
                return fieldday()->engine->getView('account/profile', ['action' => $action]);
                break;
            case "kidsinfo":
                $kidId = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_STRING);
                if ($kidId)
                {
                    $kidData = fieldday()->api->GetKidDetail($kidId);
                    $view = 'account/kidDetail';
                    $data = ['kidData' => $kidData->data->kidProfile];
                } else
                {
                    $kidData = fieldday()->api->GetKids();
                    $view = 'account/kidsinfo';
                    $data = ['kids' => $kidData->data, ['action' => $action]];
                }
                if ($kidData->statusCode !== 200)
                {
                    return fieldday()->engine->getView('account/kidsInfoError', ['message' => $kidData->message, ['action' => $action]]);
                }

                return fieldday()->engine->getView($view, $data);
                break;
            case "insurance":
                $insurance = fieldday()->api->GetInsurance();
                if ($insurance->statusCode !== 200)
                {
                    return fieldday()->engine->getView('account/kidsInfoError', ['message' => $insurance->message, 'action' => $action]);
                }

                return fieldday()->engine->getView('account/insurance', ['dentalInsurance' => $insurance->data->dentalInsurance, 'medInsurance' => $insurance->data->medInsurance, 'action' => $action]);
                break;
            default:
                return fieldday()->engine->getView('account/profile', ['action' => $action]);
        }
    }

    /**
     * Display checkout page for user
     *
     * @param Array $arg
     */
    public function fielddayCheckout($arg = [])
    {
        $cartItems = fieldday()->engine->GetCartData();
        if (!$cartItems)
        {
            return wp_sprintf('<div class="km_nodata">%s</div>', fieldday()->engine->displayText('km_empty_cart_msg', false));
        }
        return fieldday()->engine->getView('checkout/session_checkout', ['steps' => fieldday()->engine->Km_purchase_Steps()]);
    }

    /**
     * display donation form
     * @param type $arg
     * @return Html
     */
    public function fielddayDonate($arg = [])
    {
        $title = fieldday()->engine->getValue('event_name', $arg, false);
        $description = fieldday()->engine->getValue('event_description', $arg, false);
        $column = fieldday()->engine->getValue('column', $arg, false);
        $success_message = fieldday()->engine->getValue('success_message', $arg, false);
        $layoutClass = $column == 2 ? 'km_col_6' : 'km_col_12';
        return fieldday()->engine->getView('donate', ['title' => $title, 'description' => $description, 'layout_class' => $layoutClass, 'success_message' => $success_message]);
    }

}

return new fielddayShortcodes();
